#include <iostream>
#include <tuple>
#include <vector>

using namespace std;

int mod(int a, int m) {
	if(a < 0)
		return (m + a % m) % m;
	return a % m;
}

int add(int a, int b, int m) {
	return (a + b) % m;
}

int sub(int a, int b, int m) {
	return (m + a - b) % m;
}

int mul(int a, int b, int m) {
	return (a * b) % m;
}

int pow(int a, int b, int m) {
	int res = 1;
	while(b > 0) {
		if(b & 1 == 1)
			res = mul(res, a, m);
		a = mul(a, a, m);
		b >>= 1;
	}
	return res;
}

int euclid(int a, int b, int& x, int& y) {
	int r1 = a, r2 = b;
	int x1 = 1, x2 = 0;
	int y1 = 0, y2 = 1;

	while(r2 > 0) {
		int q = r1 / r2, r = r1 % r2;
		tie(r1, r2) = make_pair(r2, r1 - q * r2);
		tie(x1, x2) = make_pair(x2, x1 - q * x2);
		tie(y1, y2) = make_pair(y2, y1 - q * y2);
	}

	x = x1;
	y = y1;
	return r1;
}

int inv(int a, int m) {
	int x, y;
	int d = euclid(a, m, x, y);
	if(d != 1)
		return -1;
	return mod(x, m);
}

int crt(vector<int> as, vector<int> ns) {
	int N = 1;
	for(int n : ns)
		N *= n;

	vector<int> Ns(as.size(), N);
	for(int i = 0; i < Ns.size(); i++)
		Ns[i] /= ns[i];

	vector<int> ms(as.size());
	for(int i = 0; i < ms.size(); i++)
		ms[i] = inv(Ns[i], ns[i]);

	int x = 0;
	for(int i = 0; i < as.size(); i++)
		x = add(x, mul(as[i], mul(Ns[i], ms[i], N), N), N);

	return x;
}

int main() {
	int a, b, n;
	cin >> a >> b >> n;

	cout << crt({a, b}, {n, n+1}) << '\n';

	return 0;
}
